Learn R Programming

Uniquorn (version 1.0.8)

add_custom_vcf_to_database: Adds a custom vcf file to the three existing cancer cell line panels

Description

Adds a custom vcf file to the three existing cancer cell line panels

Usage

add_custom_vcf_to_database( vcf_file_path, ref_gen = "GRCH37", name_cl = "", safe_mode = FALSE, test_mode = FALSE)

Arguments

vcf_file_path
Input vcf file. Only one sample column allowed.
ref_gen
Reference genome version. All training sets are associated with a reference genome version. Default: GRCH37
name_cl
Name of the to-be-added cancer cell line sample. '_CUSTOM' will automatically be added as suffix.
safe_mode
Only add mutations to the database where there already are mutations found in the cannonical cancer cell lines. This is a safety mechanism against overfitting if there are too few custom training samples.
test_mode
Is this a test? Just for internal use

Value

Message if the adding has succeeded

Examples

Run this code
HT29_vcf_file = system.file("extdata/HT29.vcf.gz", package="Uniquorn");
add_custom_vcf_to_database( 
vcf_file_path = HT29_vcf_file,
name_cl = "",
ref_gen = "GRCH37",
safe_mode = FALSE,
test_mode = TRUE )

Run the code above in your browser using DataLab