Learn R Programming

Uniquorn (version 1.0.8)

create_bed_file: create_bed_file

Description

Creates BED files from the found and not found annotated mutations

Usage

create_bed_file(
sim_list,
vcf_fingerprint,
res_table,
output_file,
ref_gen,
manual_identifier
)

Arguments

sim_list
R table which contains the mutations from the training database for the cancer cell lines
vcf_fingerprint
contains the mutations that are present in the query cancer cell line's vcf file
res_table
Table containing the identification results
output_file
Path to output file
ref_gen
Reference genome version
manual_identifier
Manually enter a vector of CL name(s) whose bed files should be created, independently from them passing the detection threshold

Value

Returns a message which indicates if the BED file creation has succeeded