Learn R Programming

Uniquorn (version 1.0.8)

parse_vcf_file: parse_vcf_file

Description

Parses the vcf file and filters all information except for the start and length of variations/ mutations.

Usage

parse_vcf_file( vcf_file_path )

Arguments

vcf_file_path
Path to the vcf file on the operating system

Value

Loci-based DNA-mutational fingerprint of the cancer cell line as found in the input VCF file