Rdocumentation
powered by
Learn R Programming
Uniquorn (version 1.0.8)
re_calculate_cl_weights: Re-calculate sim_list_weights
Description
This function re-calculates the weights of mutation after a change of the training set
Usage
re_calculate_cl_weights(sim_list, ref_gen)
Arguments
sim_list
R Table which contains a mapping from mutations/ variations to their containing CLs
ref_gen
Reference genome version. All training sets are associated with a reference genome version. Default: GRCH37
Value
A list containing both the sim_list at pos 1 and sim_list_stats at pos 2 data frames.