Learn R Programming

Uniquorn (version 1.0.8)

show_contained_cls: show_contained_cls

Description

Show all cancer cell line identifier present in the database for a selected reference genome: This function shows the names, amount of mutations/ variations, overall weight of the mutations of all contained training CLs for a chosen reference genome.

Usage

show_contained_cls( ref_gen)

Arguments

ref_gen
Reference genome version. All training sets are associated with a reference genome version. Default: GRCH37

Value

R table which contains the identifier of all cancer cell line samples with the specific reference genome and the weight of all mutations

Examples

Run this code
contained_cls = show_contained_cls( 
ref_gen = "GRCH37")

Run the code above in your browser using DataLab