Learn R Programming

Uniquorn (version 1.0.8)

show_contained_mutations_for_cl: show_contained_mutations_for_cl

Description

Show all mutations present in the database for a selected cancer cell line and reference Genome

Usage

show_contained_mutations_for_cl( name_cl, ref_gen)

Arguments

name_cl
Name of the cancer cell line sample stored in the database
ref_gen
Reference genome version

Value

R table which contains all mutations associated with the defined cancer cell line and reference genome

Examples

Run this code
SK_OV_3_CELLMINER_mutations = show_contained_mutations_for_cl(
name_cl = "SK_OV_3_CELLMINER_mutations",
ref_gen = "GRCH37")

Run the code above in your browser using DataLab