Learn R Programming

Uniquorn (version 1.0.8)

show_which_cls_contain_mutation: show_which_cls_contain_mutation

Description

Show all cancer cell lines in the database which contained the specified mutation and reference Genome. Closed interval coordinates. Format mutation: CHR_START_STOP, e.g. 1_123_123

Usage

show_which_cls_contain_mutation( mutation_name, ref_gen)

Arguments

mutation_name
Name of the mutation in the format CHROMOSOME_START_STOP, e.g. '11_244501_244510'
ref_gen
Reference genome version

Value

R table which contains all cancer cell line samples which contain the specified mutation with respect to the specified reference genome version

Examples

Run this code
Cls_containing_mutations = show_which_cls_contain_mutation( 
mutation_name = "10_103354427_103354427", 
ref_gen = "GRCH37")

Run the code above in your browser using DataLab