Rdocumentation
powered by
Learn R Programming
Uniquorn (version 1.0.8)
initiate_db_and_load_data: initiate_db_and_load_data
Description
Intern utility function, loads database and return the sim_list and sim_list_stats variables.
Usage
initiate_db_and_load_data( ref_gen, request_table, load_default_db )
Arguments
ref_gen
Reference genome version. All training sets are associated with a reference genome version. Default: GRCH37
request_table
Names of the tables to be extracted from the database
load_default_db
Indicate whether the default db should be used as source for the data
Value
Returns the sim_list and sim_list_stats variable