Show all cancer cell line identifier present in the database for a selected reference genome:
This function shows the names, amount of mutations/ variations, overall weight of the mutations of all contained training CLs
for a chosen reference genome.
Usage
show_contained_cls(
ref_gen)
Arguments
ref_gen
Reference genome version. All training sets are associated with a reference genome version. Default: GRCH37
Value
R table which contains the identifier of all cancer cell line samples with the specific reference genome and the weight of all mutations