Show all mutations present in the database for a selected reference Genome:
This function shows all training-set mutations for a selected reference genome, i.e. the mutations that are being used
for identification of query cancer cell lines.
Usage
show_contained_mutations(
ref_gen )
Arguments
ref_gen
Reference genome version
Value
R Table which contains all mutations associated with a particular cancer cell line for a specified reference genome